Learn R Programming

ampliQueso (version 1.10.0)

compareCoverages: compareCoverages - camel measure for a single comparison.

Description

Comparing coverage profiles with the camel measures for the two groups of BAM files, for a given genomic region.

Usage

compareCoverages(ch, st, en, group, t1, t2, measure="DA", covdesc="covdesc")

Arguments

ch
Chromosome of the region of interest
st
Start of the region of interest
en
End of the region of interest
group
Name of the attribute/group in the experimental description (i.e. covdesc)
t1
First name of the attribute used for grouping
t2
Another name of the attribute used for grouping
measure
Method of comparison for the coverages in the selected genomic region
covdesc
Covdesc-like data frame - BAM files are read from row names

Value

A single camel value with the results of comparison.