Usage
runAQReport(iCovdesc, iBedFile, iRefSeqFile, iGroup, iT1, iT2, iTopN = 5, iMinQual, iReportFormat = "pdf", iReportType = "article",iReportPath="", iVerbose = TRUE, iVCF = NULL, iParallel=TRUE)
Arguments
iCovdesc
Covdesc-like data frame - BAM files are read from row names. Similar to covdesc in simpleaffy and rnaSeqMap - tab delimited table of BAM files and groupings. This is the table of experimental design.
iBedFile
BED file with same genomic coordinates as in BAMs (preferably standard hg19)
iRefSeqFile
Reference sequence in FASTA format used for SNPs detection. If set to NULL (by default) will skip SNP report.
iGroup
Name of the attribute/group in the experimental description (i.e. covdesc)
iT1
name of the first group from the experiment (it should be consistent with the groupings specified in covdesc file)
iT2
name of the other group from the experiment (it should be consistent with the groupings specified in covdesc file)
iTopN
number specifing top n expressed genes to be reported
iMinQual
number specifing the minimum quality of the SNPs returned by samtools used to filter out these of poor quality. Please refer to
Samtools documentation for further details on the definition of this measure.
iReportFormat
Report output format. Currently PDF only.
iReportType
LaTeX document class to be used for report generation.
iReportPath
Output path for the report. It is created in the current working directory by default.
iVerbose
Boolean specifing whether R code should be inlcude in the report, if set to FALSE only figures and tables will be included.
iParallel
Boolean specifing whether R code should be run in parallel -- it is turned on by default..